@@ -30,7 +30,7 @@ class AuthHandlersTest(unittest.TestCase):
     def do_test_handler(self, client, success, password, handler_class, **kwargs):
         h = handler_class(client, **kwargs)
         assert repr(h)
-        server_salt = kwargs.pop("server-salt", "0"*32)
+        server_salt = kwargs.pop("server-salt", b"0"*32)
         digest = kwargs.pop("digest", "xor")
         kwargs = {
             "challenge" : server_salt,
@@ -92,7 +92,7 @@ class AuthHandlersTest(unittest.TestCase):
 
     def test_uri_handler(self):
         from xpra.client.auth.uri import Handler
-        password = b"password"
+        password = "password"
         client = FakeClient()
         client.password = password
         self.do_test_handler(client, True, password, Handler)
