@@ -6,7 +6,7 @@
 
 import unittest
 
-from xpra.util import AdHocStruct
+from xpra.util.objects import AdHocStruct
 from unit.client.mixins.clientmixintest_util import ClientMixinTest
 from unit.process_test_util import DisplayContext
 
