@@ -4,9 +4,9 @@
 
 import sys
 import gi
-gi.require_version('Gtk', '3.0')
-gi.require_version('Gdk', '3.0')
-from gi.repository import Gtk  #pylint: disable=wrong-import-position
+gi.require_version('Gtk', '3.0')  # @UndefinedVariable
+gi.require_version('Gdk', '3.0')  # @UndefinedVariable
+from gi.repository import Gtk   # pylint: disable=wrong-import-position @UnresolvedImport
 
 
 def main():
