@@ -1,9 +1,10 @@
 #!/usr/bin/env python3
 
 import gi
-gi.require_version("Gtk", "3.0")
-from gi.repository import Gtk   #pylint: disable=wrong-import-position
-from xpra.gtk_common.gtk_util import get_root_size
+
+gi.require_version("Gtk", "3.0")  # @UndefinedVariable
+from gi.repository import Gtk    # pylint: disable=wrong-import-position @UnresolvedImport
+from xpra.gtk.util import get_root_size
 
 width = 400
 height = 200
@@ -11,8 +12,8 @@ def main():
 	window = Gtk.Window(type=Gtk.WindowType.TOPLEVEL)
 	window.set_size_request(width, height)
 	window.connect("delete_event", Gtk.main_quit)
-	vbox = Gtk.VBox(False, 0)
-	hbox = Gtk.HBox(False, 0)
+	vbox = Gtk.VBox(homogeneous=False, spacing=0)
+	hbox = Gtk.HBox(homogeneous=False, spacing=0)
 	vbox.pack_start(hbox, expand=False, fill=False, padding=10)
 	btn = Gtk.Button("move me")
 	hbox.pack_start(btn, expand=False, fill=False, padding=10)
