@@ -16,6 +16,8 @@ Then it morphed into something quite messy. Sorry.
 import os.path
 import sys
 import traceback
+from typing import Any
+from collections.abc import Callable, Sequence
 
 from xpra.scripts.config import read_config, make_defaults_struct, validate_config, save_config
 from xpra.gtk.signals import register_os_signals
@@ -28,13 +30,14 @@ from xpra.util.env import IgnoreWarningsContext
 from xpra.net.common import DEFAULT_PORT
 from xpra.util.thread import start_thread
 from xpra.gtk.dialogs.about import about
+from xpra.gtk.dialogs.util import hb_button
 from xpra.scripts.main import (
-    connect_to, make_client,
+    connect_to, make_client, bypass_no_gtk,
     configure_network, configure_env, configure_logging,
 )
 from xpra.common import noop
-from xpra.scripts.parsing import is_local, get_ssh_args, parse_ssh_option, get_ssh_proxy_args
-from xpra.exit_codes import RETRY_EXIT_CODES, ExitCode, exit_str
+from xpra.scripts.parsing import is_local, get_ssh_args, parse_ssh_option, get_ssh_proxy_args, get_ssl_options
+from xpra.exit_codes import RETRY_EXIT_CODES, ExitCode, ExitValue, exit_str
 from xpra.platform.info import get_username
 from xpra.log import Logger, enable_debug_for
 
@@ -113,7 +116,7 @@ def set_history_from_active(optionmenu):
         optionmenu.set_history(i)
 
 
-def has_mdns():
+def has_mdns() -> bool:
     try:
         # pylint: disable=import-outside-toplevel
         from xpra.net.mdns import get_listener_class
@@ -211,7 +214,7 @@ class ApplicationWindow:
         self.is_putty = ssh_cmd.endswith("plink") or ssh_cmd.endswith("plink.exe")
         self.is_paramiko = ssh_cmd.startswith("paramiko")
 
-    def get_launcher_validation(self):
+    def get_launcher_validation(self) -> dict:
         # TODO: since "mode" is not part of global options
         # this validation should be injected from the launcher instead
         def validate_in_list(x, options):
@@ -248,34 +251,36 @@ class ApplicationWindow:
         def show_about(*args):
             about(parent=self.window)
 
-        hb.add(button("About", "help-about", show_about))
+        hb.add(hb_button("About", "help-about", show_about))
         self.bug_tool = None
 
         def bug(*_args):
             if self.bug_tool is None:
-                from xpra.client.gtk3.bug_report import BugReport
+                from xpra.gtk.dialogs.bug_report import BugReport
                 self.bug_tool = BugReport()
                 self.bug_tool.init(show_about=False)
             self.bug_tool.show()
 
-        hb.add(button("Bug Report", "bugs", bug))
+        hb.add(hb_button("Bug Report", "bugs", bug))
         if has_mdns():
             self.mdns_gui = None
 
             def mdns(*_args):
                 if self.mdns_gui is None:
-                    from xpra.client.gtk3.mdns_gui import mdns_sessions
+                    from xpra.gtk.dialogs.mdns_gui import mdns_sessions
                     self.mdns_gui = mdns_sessions(self.config)
 
                     def close_mdns():
-                        self.mdns_gui.close()
-                        self.mdns_gui = None
+                        mdns_gui = self.mdns_gui
+                        if mdns_gui:
+                            self.mdns_gui = None
+                            mdns_gui.close()
 
                     self.mdns_gui.do_quit = close_mdns
                 else:
                     self.mdns_gui.present()
 
-            hb.add(button("Browse Sessions", "mdns", mdns))
+            hb.add(hb_button("Browse Sessions", "mdns", mdns))
         hb.show_all()
 
         vbox = Gtk.VBox(homogeneous=False, spacing=0)
@@ -553,8 +558,9 @@ class ApplicationWindow:
         self.window.present()
         self.connect_btn.grab_focus()
 
-    def run(self):
+    def run(self) -> ExitValue:
         Gtk.main()
+        return self.exit_code or 0
 
     def mode_changed(self, *_args):
         mode = self.mode_combo.get_active_text().lower()
@@ -783,6 +789,8 @@ class ApplicationWindow:
             params["local"] = is_local(self.config.host)
             params["port"] = int(self.config.port)
             params["display_name"] = f"{self.config.mode}://{self.config.host}:{self.config.port}"
+            # always populate ssl so we can auto-upgrade:
+            params["ssl-options"] = get_ssl_options(params, self.config, [])
             if self.config.mode in (MODE_SSL, MODE_WSS, MODE_QUIC) and self.nostrict_host_check.get_active():
                 params["strict-host-check"] = False
 
@@ -800,6 +808,7 @@ class ApplicationWindow:
         def raise_exception(*args):
             raise RuntimeError(*args)
 
+        bypass_no_gtk()
         self.client = make_client(raise_exception, self.config)
         self.client.show_progress(30, "client configuration")
         self.client.init(self.config)
@@ -826,6 +835,7 @@ class ApplicationWindow:
         self.current_error = None
         self.set_info_text("Connecting.")
         self.set_sensitive(False)
+        self.client.show_progress(60, "connecting")
         try:
             log("calling %s%s", connect_to,
                 (display_desc, repr_ellipsized(str(self.config)), self.set_info_text, self.ssh_failed))
@@ -940,21 +950,23 @@ class ApplicationWindow:
         if self.exit_launcher:
             sys.exit(0)
 
-    def password_ok(self, *_args):
-        self.password_entry.modify_text(Gtk.StateType.NORMAL, black)
+    def password_ok(self, *_args) -> None:
+        with IgnoreWarningsContext():
+            self.password_entry.modify_text(Gtk.StateType.NORMAL, black)
 
-    def password_warning(self, *_args):
-        self.password_entry.modify_text(Gtk.StateType.NORMAL, red)
+    def password_warning(self, *_args) -> None:
+        with IgnoreWarningsContext():
+            self.password_entry.modify_text(Gtk.StateType.NORMAL, red)
         self.password_entry.grab_focus()
 
-    def set_widget_bg_color(self, widget, is_error=False):
+    def set_widget_bg_color(self, widget, is_error=False) -> None:
         with IgnoreWarningsContext():
             widget.modify_base(Gtk.StateType.NORMAL, red if is_error else white)
 
-    def set_widget_fg_color(self, widget, is_error=False):
+    def set_widget_fg_color(self, widget, is_error=False) -> None:
         modify_fg(widget, red if is_error else black)
 
-    def update_options_from_gui(self):
+    def update_options_from_gui(self) -> None:
         def pint(vstr):
             try:
                 return int(vstr)
@@ -1028,13 +1040,13 @@ class ApplicationWindow:
         self.password_entry.set_text(password)
         self.host_entry.set_text(self.config.host)
 
-    def close_window(self, *_args):
+    def close_window(self, *_args) -> None:
         w = self.window
         if w:
             self.window = None
             w.destroy()
 
-    def destroy(self, *args):
+    def destroy(self, *args) -> bool:
         log("destroy%s", args)
         self.exit_launcher = True
         self.clean_client()
@@ -1042,7 +1054,7 @@ class ApplicationWindow:
         Gtk.main_quit()
         return False
 
-    def update_options_from_URL(self, url):
+    def update_options_from_URL(self, url: str) -> None:
         from xpra.scripts.parsing import parse_URL
         address, props = parse_URL(url)
         pa = address.split("://")
@@ -1061,12 +1073,12 @@ class ApplicationWindow:
             props["host"] = host
         self._apply_props(props)
 
-    def update_options_from_file(self, filename):
+    def update_options_from_file(self, filename: str) -> None:
         log("update_options_from_file(%s)", filename)
         props = read_config(filename)
         self._apply_props(props)
 
-    def _apply_props(self, props):
+    def _apply_props(self, props: dict[str, Any]) -> None:
         # we rely on "ssh_port" being defined on the config object
         # so try to load it from file, and define it if not present:
         options = validate_config(props,
@@ -1079,16 +1091,16 @@ class ApplicationWindow:
         self.parse_ssh()
         log("_apply_props(%s) populated config with keys '%s', ssh=%s", props, options.keys(), self.config.ssh)
 
-    def choose_session_file(self, title, action, action_button, callback):
+    def choose_session_file(self, title: str, action, action_button, callback: Callable):
         file_filter = Gtk.FileFilter()
         file_filter.set_name("Xpra")
         file_filter.add_pattern("*.xpra")
         choose_file(self.window, title, action, action_button, callback, file_filter)
 
-    def save_clicked(self, *_args):
+    def save_clicked(self, *_args) -> None:
         self.update_options_from_gui()
 
-        def do_save(filename):
+        def do_save(filename) -> None:
             # make sure the file extension is .xpra
             if os.path.splitext(filename)[-1] != ".xpra":
                 filename += ".xpra"
@@ -1096,8 +1108,8 @@ class ApplicationWindow:
 
         self.choose_session_file("Save session settings to file", Gtk.FileChooserAction.SAVE, Gtk.STOCK_SAVE, do_save)
 
-    def load_clicked(self, *_args):
-        def do_load(filename):
+    def load_clicked(self, *_args) -> None:
+        def do_load(filename) -> None:
             self.update_options_from_file(filename)
             self.update_gui_from_config()
 
@@ -1106,7 +1118,7 @@ class ApplicationWindow:
 
 # on some platforms like win32, we don't have stdout
 # and this is a GUI application, so show a dialog with the error instead
-def exception_dialog(title):
+def exception_dialog(title: str) -> None:
     md = Gtk.MessageDialog(None, Gtk.DialogFlags.DESTROY_WITH_PARENT,
                            Gtk.MessageType.INFO, Gtk.ButtonsType.CLOSE, title)
     md.format_secondary_text(traceback.format_exc())
@@ -1121,7 +1133,7 @@ def exception_dialog(title):
     Gtk.main()
 
 
-def main(argv):
+def main(argv) -> int:
     from xpra.platform import program_context
     from xpra.log import enable_color
     with program_context("Xpra-Launcher", "Xpra Connection Launcher"):
@@ -1129,7 +1141,7 @@ def main(argv):
         return do_main(argv)
 
 
-def do_main(argv):
+def do_main(argv: Sequence[str]) -> int:
     from xpra.util.system import SIGNAMES
     from xpra.scripts.main import InitExit, InitInfo
     from xpra.platform.gui import init as gui_init, ready as gui_ready
