@@ -4,6 +4,8 @@
 # Xpra is released under the terms of the GNU GPL v2, or, at your option, any
 # later version. See the file COPYING for details.
 
+from collections.abc import Sequence
+
 # Platform-specific settings for Win32.
 CAN_DAEMONIZE = False
 REINIT_WINDOWS = True
@@ -11,7 +13,7 @@ REINIT_WINDOWS = True
 CLIPBOARDS = ("CLIPBOARD",)
 CLIPBOARD_GREEDY = True
 
-SOURCE: tuple[str, ...] = ()
+SOURCE: Sequence[str] = ()
 
 EXECUTABLE_EXTENSION = "exe"
 
